@@ -10,7 +10,7 @@ from .Object import Observable
 try:
     from .appserver import AppServer
 except ImportError as e:
-    print "[wise] Error: AppServer not available:", e
+    print "Error:", e
 
 from .utils import initialize, dirname, Application, proxy_as_servant
 
